..
      Copyright 2010-2012 United States Government as represented by the
      Administrator of the National Aeronautics and Space Administration.
      All Rights Reserved.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

Welcome to Manila's developer documentation!
============================================

Manila is an OpenStack project to provide "Shared Filesystems as a service".

* **Component based architecture**: Quickly add new behaviors
* **Highly available**: Scale to very serious workloads
* **Fault-Tolerant**: Isolated processes avoid cascading failures
* **Recoverable**: Failures should be easy to diagnose, debug, and rectify
* **Open Standards**: Be a reference implementation for a community-driven api

This documentation is generated by the Sphinx toolkit and lives in the source
tree. Additional draft and project documentation on Manila and other components of OpenStack can
be found on the `OpenStack wiki`_. Cloud administrators, refer to `docs.openstack.org`_.

.. _`OpenStack wiki`: http://wiki.openstack.org
.. _`docs.openstack.org`: http://docs.openstack.org



Installing Manila
=================

.. toctree::
   :maxdepth: 1

   install/index

Admin Docs
==========

.. toctree::
   :maxdepth: 1

   admin/shared-file-systems-intro.rst

Contributor/Developer Docs
==========================

.. toctree::
   :maxdepth: 1

   contributor/index

Command Line Interface Documentation
====================================

.. toctree::
   :maxdepth: 1

   cli/index


Configuration Reference
=======================

.. toctree::
   :maxdepth: 1

   configuration/shared-file-systems

Other Reference
===============

.. toctree::
   :maxdepth: 1

   reference/index

User Documentaton
=================

.. toctree::
   :maxdepth: 1

   user/index

Indices and tables
==================

* :ref:`genindex`
